@@ -37,7 +37,7 @@ import Data.Either (isRight)
 -- tr' x = trace (show x) x
 
 -- | Transforms an expression tree to equivalent LaTeX with the default
--- packages (amsmath and amssymb)
+-- packages (amsmath, amssymb, and cancel)
 writeTeX :: [Exp] -> T.Text
 writeTeX = writeTeXWith defaultEnv
 
@@ -262,6 +262,12 @@ writeExp (EBoxed e) = do
         tell [ControlSeq "\\boxed"]
         tellGroup (writeExp e)
       else writeExp e
+writeExp (ECancel st e) = do
+  case st of
+    ForwardSlash -> tell [ControlSeq "\\cancel"]
+    BackSlash -> tell [ControlSeq "\\bcancel"]
+    XSlash -> tell [ControlSeq "\\xcancel"]
+  tellGroup (writeExp e)
 writeExp (EScaled size e)
   | case e of
          (ESymbol Open _)  -> True
